﻿using Syncfusion.PMML;
using System;
using System.Collections.Generic;
using System.Data;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace _130026
{
    class Program
    {
        static void Main(string[] args)
        {
            // This sample demonstrates how to obtain predicted results from DataTable using Syncfusion.PMML library.
            // Here, we have conisdered "Tips" data, from which we'll predict the "tip" amount based on the below input columns/factors.

            // Create a DataTable (Consider this table is obtained from a dataset)
            DataTable dataTable = new DataTable("Tips");

            // Add columns to the datatable
            dataTable.Columns.Add("total_bill");
            dataTable.Columns.Add("sex");
            dataTable.Columns.Add("smoker");
            dataTable.Columns.Add("day");
            dataTable.Columns.Add("time");
            dataTable.Columns.Add("size");
            
            // Add rows to the datatable
            dataTable.Rows.Add(16.99, "Female", "No", "Sun", "Dinner", 2);
            dataTable.Rows.Add(41.19, "Male", "No", "Thur", "Lunch", 5);

            // PMMLEvaluator instance
            PMMLEvaluator evaluator = new PMMLEvaluatorFactory().GetPMMLEvaluatorInstance("../../Tips.pmml");

            // Convert datatable and get predicted results
            foreach (DataRow dataRow in dataTable.Rows)
            {
                // Dictionary object
                var tipsInputData = new Dictionary<string, object>();
                foreach (var column in dataTable.Columns)
                {
                    tipsInputData.Add(column.ToString(), dataRow[column.ToString()]);
                }

                // Anonymous object
                //var tipsInputData = new
                //{
                //    total_bill = dataRow["total_bill"],
                //    sex = dataRow["sex"],
                //    smoker = dataRow["smoker"],
                //    day = dataRow["day"],
                //    time = dataRow["time"],
                //    size = dataRow["size"]
                //};

                // ExpandoObject 
                //dynamic tipsInputData = new ExpandoObject();
                //tipsInputData.total_bill = dataRow["total_bill"];
                //tipsInputData.sex = dataRow["sex"];
                //tipsInputData.smoker = dataRow["smoker"];
                //tipsInputData.day = dataRow["day"];
                //tipsInputData.time = dataRow["time"];
                //tipsInputData.size = dataRow["size"];

                // Gets the Predicted Tip Amount
                PredictedResult tipAmount = evaluator.GetResult(tipsInputData, null);

                // Print the predicted result value
                Console.WriteLine(tipAmount.PredictedValue);
            }

            Console.ReadKey();
        }
    }
}
